Struct PicoStr

pub struct PicoStr(/* private fields */);
An interned string representation that is cheap to copy and hash, but more expensive to access.

This type takes up 8 bytes and is copyable and null-optimized (i.e. Option<PicoStr> also takes 8 bytes).

Supports compile-time string interning via PicoStr::constant in two flavors:

  • Strings of length at most 12 containing only chars from ‘a’-‘z’, ‘1’-‘4’, and ‘-’ are stored inline in the number
  • Other strings can be compile-time interned the same way, but must first be added to the list in exceptions::LIST.

No such restrictions apply at runtime (via PicoStr::intern).

Implementations

Source

impl PicoStr

pub fn intern(string: &str) -> PicoStr

Intern a string at runtime.

pub const fn constant(string: &'static str) -> PicoStr

Creates a compile-time constant PicoStr.

Should only be used in const contexts because it can panic.

pub const fn try_constant(string: &str) -> Result<PicoStr, EncodingError>

Try to intern a string statically at compile-time.

pub fn resolve(self) -> ResolvedPicoStr

Resolve to a decoded string.